@@ -28,6 +28,9 @@ class SQLOptions(object):
         self.m_SQL_OptionList.append({"Name": "FLOAT_FORMAT", "Value": "%.7g", "Comments": '----'})
         self.m_SQL_OptionList.append({"Name": "DOUBLE_FORMAT", "Value": "%.10g", "Comments": '----'})
 
+        self.m_SQL_OptionList.append({"Name": "JDBCURL", "Value": "", "Comments": '----'})
+        self.m_SQL_OptionList.append({"Name": "JDBCPROP", "Value": "", "Comments": '----'})
+
     def get(self, p_ParameterName):
         """根据参数名称返回参数，若不存在该参数，返回None."""
         for item in self.m_SQL_OptionList:
